@@ -32,6 +32,8 @@ def func(x):
         print("single \
                 continued line ")
         print('single line')
+    if y := x:
+        anext(a)
     return float(len(a2))
 
 
@@ -118,9 +120,25 @@ match(command.split()):
     case ["quit"]:
         print("Goodbye!")
 
+def func1():
+    yield 1
+    yield  from [func(), 1, 2, "3"]
+    # invalid, "from" no longer part of "yield from"
+    yield, from 1
+
+async def func2():
+    await asyncio.sleep(1)
+
+assert cond, \
+    "bla bla"
+
+print('dsdsa' \
+      'dsdasw'
+      'dsadsa')
+
 "\\\\\\\\\\ENSURE THAT THIS AND THE FOLLOWING LINES ARE AT THE END OF THE FILE\\\\\\\\\\ \
 "
-a = 'otherwise all succeeding lines will be
+a = 'otherwise the next line will be
 stuck on the Error attribute'
 br"Strings delimited by single quotes (' or ")
 can NOT be defined across multiple lines
