@@ -26,8 +26,6 @@
 #include <QCborMap>
 #include <QCoreApplication>
 #include <QFile>
-#include <QHash>
-#include <QStringList>
 #include <QXmlStreamReader>
 
 #include <algorithm>
@@ -44,7 +42,7 @@ DefinitionData::DefinitionData()
 DefinitionData::~DefinitionData() = default;
 
 Definition::Definition()
-    : d(new DefinitionData)
+    : d(std::make_shared<DefinitionData>())
 {
     d->q = *this;
 }
@@ -58,6 +56,9 @@ Definition &Definition::operator=(const Definition &) = default;
 Definition::Definition(std::shared_ptr<DefinitionData> &&dd)
     : d(std::move(dd))
 {
+    if (!d) {
+        Definition().d.swap(d);
+    }
 }
 
 bool Definition::operator==(const Definition &other) const
@@ -85,6 +86,11 @@ QString Definition::name() const
     return d->name;
 }
 
+QStringList Definition::alternativeNames() const
+{
+    return d->alternativeNames;
+}
+
 QString Definition::translatedName() const
 {
     if (d->translatedName.isEmpty()) {
@@ -225,7 +231,7 @@ QList<Format> Definition::formats() const
     d->load();
 
     // sort formats so that the order matches the order of the itemDatas in the xml files.
-    auto formatList = QList<Format>::fromList(d->formats.values());
+    auto formatList = d->formats.values();
     std::sort(formatList.begin(), formatList.end(), [](const KSyntaxHighlighting::Format &lhs, const KSyntaxHighlighting::Format &rhs) {
         return lhs.id() < rhs.id();
     });
@@ -454,6 +460,9 @@ bool DefinitionData::loadMetaData(const QString &file, const QCborMap &obj)
     hidden = obj.value(QLatin1String("hidden")).toBool();
     fileName = file;
 
+    const auto names = obj.value(QLatin1String("alternativeNames")).toString();
+    alternativeNames = names.split(QLatin1Char(';'), Qt::SkipEmptyParts);
+
     const auto exts = obj.value(QLatin1String("extensions")).toString();
     extensions = exts.split(QLatin1Char(';'), Qt::SkipEmptyParts);
 
@@ -473,6 +482,10 @@ bool DefinitionData::loadLanguage(QXmlStreamReader &reader)
     }
 
     name = reader.attributes().value(QLatin1String("name")).toString();
+    const auto names = reader.attributes().value(QLatin1String("alternativeNames"));
+    for (const auto &n : names.split(QLatin1Char(';'), Qt::SkipEmptyParts)) {
+        alternativeNames.push_back(n.toString());
+    }
     section = reader.attributes().value(QLatin1String("section")).toString();
     // toFloat instead of toInt for backward compatibility with old Kate files
     version = reader.attributes().value(QLatin1String("version")).toFloat();
@@ -813,8 +826,8 @@ bool DefinitionData::checkKateVersion(QStringView verStr)
         qCWarning(Log) << "Skipping" << fileName << "due to having no valid kateversion attribute:" << verStr;
         return false;
     }
-    const auto major = verStr.left(idx).toString().toInt();
-    const auto minor = verStr.mid(idx + 1).toString().toInt();
+    const auto major = verStr.left(idx).toInt();
+    const auto minor = verStr.mid(idx + 1).toInt();
 
     if (major > KSYNTAXHIGHLIGHTING_VERSION_MAJOR || (major == KSYNTAXHIGHLIGHTING_VERSION_MAJOR && minor > KSYNTAXHIGHLIGHTING_VERSION_MINOR)) {
         qCWarning(Log) << "Skipping" << fileName << "due to being too new, version:" << verStr;
@@ -842,34 +855,20 @@ void DefinitionData::addImmediateIncludedDefinition(const Definition &def)
 
 DefinitionRef::DefinitionRef() = default;
 
-DefinitionRef::DefinitionRef(const Definition &def)
+DefinitionRef::DefinitionRef(const Definition &def) noexcept
     : d(def.d)
 {
 }
 
-DefinitionRef::DefinitionRef(Definition &&def)
-    : d(std::move(def.d))
-{
-}
-
-DefinitionRef &DefinitionRef::operator=(const Definition &def)
+DefinitionRef &DefinitionRef::operator=(const Definition &def) noexcept
 {
     d = def.d;
     return *this;
 }
 
-DefinitionRef &DefinitionRef::operator=(Definition &&def)
-{
-    d = std::move(def.d);
-    return *this;
-}
-
 Definition DefinitionRef::definition() const
 {
-    if (!d.expired()) {
-        return Definition(d.lock());
-    }
-    return Definition();
+    return Definition(d.lock());
 }
 
 bool DefinitionRef::operator==(const DefinitionRef &other) const
